@@ -7,7 +7,7 @@
 #  define AVOGADRORENDERING_NO_EXPORT
 #else
 #  ifndef AVOGADRORENDERING_EXPORT
-#    ifdef AvogadroRendering_EXPORTS
+#    ifdef Rendering_EXPORTS
         /* We are building this library */
 #      define AVOGADRORENDERING_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,13 +23,20 @@
 
 #ifndef AVOGADRORENDERING_DEPRECATED
 #  define AVOGADRORENDERING_DEPRECATED __attribute__ ((__deprecated__))
-#  define AVOGADRORENDERING_DEPRECATED_EXPORT AVOGADRORENDERING_EXPORT __attribute__ ((__deprecated__))
-#  define AVOGADRORENDERING_DEPRECATED_NO_EXPORT AVOGADRORENDERING_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define AVOGADRORENDERING_NO_DEPRECATED
+#ifndef AVOGADRORENDERING_DEPRECATED_EXPORT
+#  define AVOGADRORENDERING_DEPRECATED_EXPORT AVOGADRORENDERING_EXPORT AVOGADRORENDERING_DEPRECATED
 #endif
 
+#ifndef AVOGADRORENDERING_DEPRECATED_NO_EXPORT
+#  define AVOGADRORENDERING_DEPRECATED_NO_EXPORT AVOGADRORENDERING_NO_EXPORT AVOGADRORENDERING_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef AVOGADRORENDERING_NO_DEPRECATED
+#    define AVOGADRORENDERING_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* AVOGADRORENDERING_EXPORT_H */
